@@ -499,3 +499,12 @@ def cli_secret_grant(obj, base_profile, secret_file):
     from suite_py.commands.secret import Secret
 
     Secret(obj["project"], obj["config"], "grant", base_profile, secret_file).run()
+
+
+@main.command("batch-job", help="Run batch job on kube")
+@click.argument("environment", type=click.Choice(("staging", "production")))
+@click.pass_obj
+def cli_run_batch_job(obj, environment):
+    from suite_py.commands.batch_job import BatchJob
+
+    BatchJob(obj["project"], obj["config"], obj["tokens"], environment).run()
