@@ -117,6 +117,17 @@ class DroneHandler:
         except Exception:
             return []
 
+    def get_builds_from_branch(self, branch):
+        try:
+            builds = requests.get(
+                f"{BASEURL}/api/repos/primait/{self._repo}/builds?branch={branch}&per_page=100",
+                headers={"Authorization": f"Bearer {self._token}"},
+            ).json()
+
+            return [b for b in builds if b["event"] == "push"]
+        except Exception:
+            return []
+
     def get_build_number_from_tag(self, tag):
         attempts = 0
         while attempts < 3:
@@ -148,6 +159,9 @@ class DroneHandler:
             logger.error(f"Unable to trigger drone build, exiting with error: {e}")
             sys.exit(-1)
 
+    def promote_staging(self, build, target, querystring):
+        return self.promote(build, target, querystring)
+
     def promote_production(self, tag, target, querystring):
         build = self.get_build_number_from_tag(tag)
         if build:
